==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/KeyValuePairFluentImpl.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import io.fabric8.docker.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class KeyValuePairFluentImpl<A extends KeyValuePairFluent<A>> extends io.fabric8.docker.api.builder.BaseFluent<A> implements KeyValuePairFluent<A>{

    private String Key;
    private String Value;

    public KeyValuePairFluentImpl(){
    }
    public KeyValuePairFluentImpl(KeyValuePair instance){
            this.withKey(instance.getKey()); 
            this.withValue(instance.getValue()); 
    }

    public String getKey(){
            return this.Key;
    }

    public A withKey(String Key){
            this.Key=Key; return (A) this;
    }

    public String getValue(){
            return this.Value;
    }

    public A withValue(String Value){
            this.Value=Value; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KeyValuePairFluentImpl that = (KeyValuePairFluentImpl) o;
            if (Key != null ? !Key.equals(that.Key) :that.Key != null) return false;
            if (Value != null ? !Value.equals(that.Value) :that.Value != null) return false;
            return true;
    }




}

==> docker-model-1.2.1-sources.jar: annotations/io/fabric8/docker/api/model/KeyValuePairFluentImpl.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.docker.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class KeyValuePairFluentImpl<A extends KeyValuePairFluent<A>> extends io.fabric8.docker.api.builder.BaseFluent<A> implements KeyValuePairFluent<A>{

    private String Key;
    private String Value;

    public KeyValuePairFluentImpl(){
    }
    public KeyValuePairFluentImpl(KeyValuePair instance){
            this.withKey(instance.getKey()); 
            this.withValue(instance.getValue()); 
    }

    public String getKey(){
            return this.Key;
    }

    public A withKey(String Key){
            this.Key=Key; return (A) this;
    }

    public Boolean hasKey(){
            return this.Key!=null;
    }

    public String getValue(){
            return this.Value;
    }

    public A withValue(String Value){
            this.Value=Value; return (A) this;
    }

    public Boolean hasValue(){
            return this.Value!=null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KeyValuePairFluentImpl that = (KeyValuePairFluentImpl) o;
            if (Key != null ? !Key.equals(that.Key) :that.Key != null) return false;
            if (Value != null ? !Value.equals(that.Value) :that.Value != null) return false;
            return true;
    }




}
